@@ -36,33 +36,34 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <X11/keysym.h>
-#include <mateconf/mateconf-client.h>
+#include <gio/gio.h>
+#include <dconf.h>
 
 #include "mate-settings-profile.h"
 #include "msd-keybindings-manager.h"
+#include "dconf-util.h"
 
 #include "msd-keygrab.h"
 #include "eggaccelerators.h"
 
-#define MATECONF_BINDING_DIR "/desktop/mate/keybindings"
-#define ALLOWED_KEYS_KEY MATECONF_BINDING_DIR "/allowed_keys"
+#define GSETTINGS_KEYBINDINGS_DIR "/org/mate/desktop/keybindings/"
+#define CUSTOM_KEYBINDING_SCHEMA "org.mate.control-center.keybinding"
 
 #define MSD_KEYBINDINGS_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MSD_TYPE_KEYBINDINGS_MANAGER, MsdKeybindingsManagerPrivate))
 
 typedef struct {
         char *binding_str;
         char *action;
-        char *mateconf_key;
+        char *settings_path;
         Key   key;
         Key   previous_key;
 } Binding;
 
 struct MsdKeybindingsManagerPrivate
 {
-        GSList *binding_list;
-	GSList *allowed_keys;
-        GSList *screens;
-        guint   notify;
+        DConfClient *client;
+        GSList      *binding_list;
+        GSList      *screens;
 };
 
 static void     msd_keybindings_manager_class_init  (MsdKeybindingsManagerClass *klass);
@@ -100,18 +101,6 @@ get_screens_list (void)
         return list;
 }
 
-static char *
-entry_get_string (MateConfEntry *entry)
-{
-        MateConfValue *value = mateconf_entry_get_value (entry);
-
-        if (value == NULL || value->type != MATECONF_VALUE_STRING) {
-                return NULL;
-        }
-
-        return g_strdup (mateconf_value_get_string (value));
-}
-
 static gboolean
 parse_binding (Binding *binding)
 {
@@ -126,7 +115,8 @@ parse_binding (Binding *binding)
 
         if (binding->binding_str == NULL ||
             binding->binding_str[0] == '\0' ||
-            strcmp (binding->binding_str, "Disabled") == 0) {
+            g_strcmp0 (binding->binding_str, "Disabled") == 0 ||
+            g_strcmp0 (binding->binding_str, "disabled") == 0 ) {
                 return FALSE;
         }
 
@@ -136,7 +126,7 @@ parse_binding (Binding *binding)
                                                  &binding->key.state);
 
         if (!success)
-            g_warning (_("Key binding (%s) is invalid"), binding->mateconf_key);
+            g_warning (_("Key binding (%s) is invalid"), binding->settings_path);
 
         return success;
 }
@@ -148,61 +138,40 @@ compare_bindings (gconstpointer a,
         Binding *key_a = (Binding *) a;
         char    *key_b = (char *) b;
 
-        return strcmp (key_b, key_a->mateconf_key);
+        return g_strcmp0 (key_b, key_a->settings_path);
 }
 
 static gboolean
 bindings_get_entry (MsdKeybindingsManager *manager,
-                    MateConfClient           *client,
-                    const char            *subdir)
+                    const char            *settings_path)
 {
-        Binding *new_binding;
-        GSList  *tmp_elem;
-        GSList  *list;
-        GSList  *li;
-        char    *mateconf_key;
-        char    *action = NULL;
-        char    *key = NULL;
+        GSettings *settings;
+        Binding   *new_binding;
+        GSList    *tmp_elem;
+        char      *action = NULL;
+        char      *key = NULL;
 
-        g_return_val_if_fail (subdir != NULL, FALSE);
-
-        mateconf_key = g_path_get_basename (subdir);
-
-        if (!mateconf_key) {
+        if (!settings_path) {
                 return FALSE;
         }
 
         /* Get entries for this binding */
-        list = mateconf_client_all_entries (client, subdir, NULL);
-
-        for (li = list; li != NULL; li = li->next) {
-                MateConfEntry *entry = li->data;
-                char *key_name = g_path_get_basename (mateconf_entry_get_key (entry));
-
-                if (key_name == NULL) {
-                        /* ignore entry */
-                } else if (strcmp (key_name, "action") == 0) {
-                        action = entry_get_string (entry);
-                } else if (strcmp (key_name, "binding") == 0) {
-                        key = entry_get_string (entry);
-                }
-
-                g_free (key_name);
-                mateconf_entry_free (entry);
-        }
-
-        g_slist_free (list);
+        settings = g_settings_new_with_path (CUSTOM_KEYBINDING_SCHEMA, settings_path);
+        action = g_settings_get_string (settings, "action");
+        key = g_settings_get_string (settings, "binding");
+        g_object_unref (settings);
 
         if (!action || !key) {
-                g_warning (_("Key binding (%s) is incomplete"), mateconf_key);
-                g_free (mateconf_key);
+                g_warning (_("Key binding (%s) is incomplete"), settings_path);
                 g_free (action);
                 g_free (key);
                 return FALSE;
         }
 
+        g_debug ("keybindings: get entries from '%s' (action: '%s', key: '%s')", settings_path, action, key);
+
         tmp_elem = g_slist_find_custom (manager->priv->binding_list,
-                                        mateconf_key,
+                                        settings_path,
                                         compare_bindings);
 
         if (!tmp_elem) {
@@ -211,7 +180,7 @@ bindings_get_entry (MsdKeybindingsManager *manager,
                 new_binding = (Binding *) tmp_elem->data;
                 g_free (new_binding->binding_str);
                 g_free (new_binding->action);
-                g_free (new_binding->mateconf_key);
+                g_free (new_binding->settings_path);
 
                 new_binding->previous_key.keysym = new_binding->key.keysym;
                 new_binding->previous_key.state = new_binding->key.state;
@@ -221,7 +190,7 @@ bindings_get_entry (MsdKeybindingsManager *manager,
 
         new_binding->binding_str = key;
         new_binding->action = action;
-        new_binding->mateconf_key = mateconf_key;
+        new_binding->settings_path = g_strdup (settings_path);
 
         if (parse_binding (new_binding)) {
                 if (!tmp_elem)
@@ -229,7 +198,7 @@ bindings_get_entry (MsdKeybindingsManager *manager,
         } else {
                 g_free (new_binding->binding_str);
                 g_free (new_binding->action);
-                g_free (new_binding->mateconf_key);
+                g_free (new_binding->settings_path);
                 g_free (new_binding->previous_key.keycodes);
                 g_free (new_binding);
 
@@ -241,6 +210,52 @@ bindings_get_entry (MsdKeybindingsManager *manager,
         return TRUE;
 }
 
+static void
+bindings_clear (MsdKeybindingsManager *manager)
+{
+        MsdKeybindingsManagerPrivate *p = manager->priv;
+        GSList *l;
+
+        if (p->binding_list != NULL)
+        {
+                for (l = p->binding_list; l; l = l->next) {
+                        Binding *b = l->data;
+                        g_free (b->binding_str);
+                        g_free (b->action);
+                        g_free (b->settings_path);
+                        g_free (b->previous_key.keycodes);
+                        g_free (b->key.keycodes);
+                        g_free (b);
+                }
+                g_slist_free (p->binding_list);
+                p->binding_list = NULL;
+        }
+}
+
+static void
+bindings_get_entries (MsdKeybindingsManager *manager)
+{
+        gchar **custom_list = NULL;
+        gint i;
+
+        bindings_clear (manager);
+
+        custom_list = dconf_util_list_subdirs (GSETTINGS_KEYBINDINGS_DIR, FALSE);
+
+        if (custom_list != NULL)
+        {
+                for (i = 0; custom_list[i] != NULL; i++)
+                {
+                        gchar *settings_path;
+                        settings_path = g_strdup_printf("%s%s", GSETTINGS_KEYBINDINGS_DIR, custom_list[i]);
+                        bindings_get_entry (manager, settings_path);
+                        g_free (settings_path);
+                }
+                g_strfreev (custom_list);
+        }
+
+}
+
 static gboolean
 same_keycode (const Key *key, const Key *other)
 {
@@ -330,13 +345,6 @@ binding_register_keys (MsdKeybindingsManager *manager)
         for (li = manager->priv->binding_list; li != NULL; li = li->next) {
                 Binding *binding = (Binding *) li->data;
 
-		if (manager->priv->allowed_keys != NULL &&
-                    !g_slist_find_custom (manager->priv->allowed_keys,
-                                          binding->mateconf_key,
-                                          (GCompareFunc) g_strcmp0)) {
-                        continue;
-		}
-
                 if (!same_key (&binding->previous_key, &binding->key)) {
                         /* Ungrab key if it changed and not clashing with previously set binding */
                         if (!key_already_used (manager, binding)) {
@@ -364,6 +372,7 @@ binding_register_keys (MsdKeybindingsManager *manager)
                 gdk_flush ();
         if (gdk_error_trap_pop ())
                 g_warning ("Grab failed for some keys, another application may already have access the them.");
+
 }
 
 extern char **environ;
@@ -507,56 +516,31 @@ keybindings_filter (GdkXEvent             *gdk_xevent,
 }
 
 static void
-bindings_callback (MateConfClient           *client,
-                   guint                  cnxn_id,
-                   MateConfEntry            *entry,
+bindings_callback (DConfClient           *client,
+        #ifdef HAVE_DCONF_0_13
+                   gchar                 *prefix,
+                   GStrv                  changes,
+        #else
+                   const gchar           *path,
+                   const gchar * const   *items,
+                   gint                   n_items,
+        #endif
+                   gchar                 *tag,
                    MsdKeybindingsManager *manager)
 {
-        char** key_elems;
-        char* binding_entry;
+        g_debug ("keybindings: received 'changed' signal from dconf");
 
-        if (strcmp (mateconf_entry_get_key (entry), ALLOWED_KEYS_KEY) == 0) {
-                g_slist_foreach (manager->priv->allowed_keys, (GFunc)g_free, NULL);
-                g_slist_free (manager->priv->allowed_keys);
-                manager->priv->allowed_keys = mateconf_client_get_list (client,
-                                                                     ALLOWED_KEYS_KEY,
-                                                                     MATECONF_VALUE_STRING,
-                                                                     NULL);
-        }
-        else {
-                /* ensure we get binding dir not a sub component */
-                key_elems = g_strsplit (mateconf_entry_get_key (entry), "/", 15);
-                binding_entry = g_strdup_printf ("/%s/%s/%s/%s",
-                                                 key_elems[1],
-                                                 key_elems[2],
-                                                 key_elems[3],
-                                                 key_elems[4]);
-                g_strfreev (key_elems);
+        binding_unregister_keys (manager);
 
-                bindings_get_entry (manager, client, binding_entry);
-                g_free (binding_entry);
-        }
+        bindings_get_entries (manager);
 
         binding_register_keys (manager);
 }
 
-static guint
-register_config_callback (MsdKeybindingsManager   *manager,
-                          MateConfClient             *client,
-                          const char              *path,
-                          MateConfClientNotifyFunc    func)
-{
-        mateconf_client_add_dir (client, path, MATECONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-        return mateconf_client_notify_add (client, path, func, manager, NULL, NULL);
-}
-
 gboolean
 msd_keybindings_manager_start (MsdKeybindingsManager *manager,
                                GError               **error)
 {
-        MateConfClient *client;
-        GSList      *list;
-        GSList      *li;
         GdkDisplay  *dpy;
         GdkScreen   *screen;
         int          screen_num;
@@ -565,18 +549,6 @@ msd_keybindings_manager_start (MsdKeybindingsManager *manager,
         g_debug ("Starting keybindings manager");
         mate_settings_profile_start (NULL);
 
-        client = mateconf_client_get_default ();
-
-        manager->priv->notify = register_config_callback (manager,
-                                                          client,
-                                                          MATECONF_BINDING_DIR,
-                                                          (MateConfClientNotifyFunc) bindings_callback);
-
-        manager->priv->allowed_keys = mateconf_client_get_list (client,
-                                                             ALLOWED_KEYS_KEY,
-                                                             MATECONF_VALUE_STRING,
-                                                             NULL);
-
         dpy = gdk_display_get_default ();
         screen_num = gdk_display_get_n_screens (dpy);
 
@@ -586,20 +558,25 @@ msd_keybindings_manager_start (MsdKeybindingsManager *manager,
                                        (GdkFilterFunc) keybindings_filter,
                                        manager);
         }
-
-        list = mateconf_client_all_dirs (client, MATECONF_BINDING_DIR, NULL);
         manager->priv->screens = get_screens_list ();
 
-        for (li = list; li != NULL; li = li->next) {
-                bindings_get_entry (manager, client, li->data);
-                g_free (li->data);
-        }
-
-        g_slist_free (list);
-        g_object_unref (client);
-
+        manager->priv->binding_list = NULL;
+        bindings_get_entries (manager);
         binding_register_keys (manager);
 
+        /* DConf has different API between versions:
+         * http://developer.gnome.org/dconf/0.12/DConfClient.html
+         * http://developer.gnome.org/dconf/0.14/DConfClient.html
+         */
+        #ifdef HAVE_DCONF_0_13
+        manager->priv->client = dconf_client_new ();
+        dconf_client_watch_fast (manager->priv->client, GSETTINGS_KEYBINDINGS_DIR);
+        g_signal_connect (manager->priv->client, "changed", G_CALLBACK (bindings_callback), manager);
+        #else
+        manager->priv->client = dconf_client_new (NULL, (DConfWatchFunc) bindings_callback, manager, NULL);
+        dconf_client_watch (manager->priv->client, GSETTINGS_KEYBINDINGS_DIR, NULL, NULL);
+        #endif
+
         mate_settings_profile_end (NULL);
 
         return TRUE;
@@ -613,12 +590,9 @@ msd_keybindings_manager_stop (MsdKeybindingsManager *manager)
 
         g_debug ("Stopping keybindings manager");
 
-        if (p->notify != 0) {
-                MateConfClient *client = mateconf_client_get_default ();
-                mateconf_client_remove_dir (client, MATECONF_BINDING_DIR, NULL);
-                mateconf_client_notify_remove (client, p->notify);
-                g_object_unref (client);
-                p->notify = 0;
+        if (p->client != NULL) {
+                g_object_unref (p->client);
+                p->client = NULL;
         }
 
         for (l = p->screens; l; l = l->next) {
@@ -629,21 +603,10 @@ msd_keybindings_manager_stop (MsdKeybindingsManager *manager)
         }
 
         binding_unregister_keys (manager);
+        bindings_clear (manager);
 
         g_slist_free (p->screens);
         p->screens = NULL;
-
-        for (l = p->binding_list; l; l = l->next) {
-                Binding *b = l->data;
-                g_free (b->binding_str);
-                g_free (b->action);
-                g_free (b->mateconf_key);
-                g_free (b->previous_key.keycodes);
-                g_free (b->key.keycodes);
-                g_free (b);
-        }
-        g_slist_free (p->binding_list);
-        p->binding_list = NULL;
 }
 
 static void
