@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <gtk/gtk.h>
@@ -62,12 +62,8 @@ locate_pointer_paint (MsdLocatePointerData *data,
 
   progress = data->progress;
 
-	#if GTK_CHECK_VERSION(3, 0, 0)
-		width = gdk_window_get_width(GDK_WINDOW(data->window));
-		height = gdk_window_get_height(GDK_WINDOW(data->window));
-	#else
-		gdk_drawable_get_size(data->window, &width, &height);
-	#endif
+  width = gdk_window_get_width (data->window);
+  height = gdk_window_get_height (data->window);
 
   style = gtk_widget_get_style (data->widget);
   color = style->bg[GTK_STATE_SELECTED];
@@ -180,7 +176,7 @@ timeline_frame_cb (MsdTimeline *timeline,
       data->progress += CIRCLES_PROGRESS_INTERVAL;
     }
 
-  screen = gdk_drawable_get_screen (data->window);
+  screen = gdk_window_get_screen (data->window);
   gdk_window_get_pointer (gdk_screen_get_root_window (screen),
 			  &cursor_x, &cursor_y, NULL);
   gdk_window_move (data->window,
@@ -242,15 +238,15 @@ create_window (MsdLocatePointerData *data,
   GdkColormap *colormap;
   GdkVisual *visual;
   GdkWindowAttr attributes;
+  gint attributes_mask;
 
   colormap = gdk_screen_get_rgba_colormap (screen);
   visual = gdk_screen_get_rgba_visual (screen);
 
-  if (!colormap)
-    {
-      colormap = gdk_screen_get_rgb_colormap (screen);
-      visual = gdk_screen_get_rgb_visual (screen);
-    }
+  attributes_mask = GDK_WA_X | GDK_WA_Y;
+
+  if (colormap)
+    attributes_mask = attributes_mask | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
   attributes.window_type = GDK_WINDOW_TEMP;
   attributes.wclass = GDK_INPUT_OUTPUT;
@@ -262,7 +258,7 @@ create_window (MsdLocatePointerData *data,
 
   data->window = gdk_window_new (gdk_screen_get_root_window (screen),
 				 &attributes,
-				 GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP);
+				 attributes_mask);
 
   gdk_window_set_user_data (data->window, data->widget);
 }
@@ -301,8 +297,7 @@ move_locate_pointer_window (MsdLocatePointerData *data,
 {
   gint cursor_x, cursor_y;
   GdkBitmap *mask;
-  GdkColor col;
-  GdkGC *gc;
+  cairo_t *cr;
 
   gdk_window_get_pointer (gdk_screen_get_root_window (screen), &cursor_x, &cursor_y, NULL);
 
@@ -311,18 +306,18 @@ move_locate_pointer_window (MsdLocatePointerData *data,
                           cursor_y - WINDOW_SIZE / 2,
                           WINDOW_SIZE, WINDOW_SIZE);
 
-  col.pixel = 0;
   mask = gdk_pixmap_new (data->window, WINDOW_SIZE, WINDOW_SIZE, 1);
 
-  gc = gdk_gc_new (mask);
-  gdk_gc_set_foreground (gc, &col);
-  gdk_draw_rectangle (mask, gc, TRUE, 0, 0, WINDOW_SIZE, WINDOW_SIZE);
+  cr = gdk_cairo_create (mask);
+  cairo_set_source_rgb (cr, 0., 0., 0.);
+  cairo_rectangle (cr, 0., 0., WINDOW_SIZE, WINDOW_SIZE);
+  cairo_fill (cr);
+  cairo_destroy (cr);
 
   /* allow events to happen through the window */
   gdk_window_input_shape_combine_mask (data->window, mask, 0, 0);
 
   g_object_unref (mask);
-  g_object_unref (gc);
 }
 
 void
@@ -335,7 +330,7 @@ msd_locate_pointer (GdkScreen *screen)
   msd_timeline_rewind (data->timeline);
 
   /* Create again the window if it is not for the current screen */
-  if (gdk_screen_get_number (screen) != gdk_screen_get_number (gdk_drawable_get_screen (data->window)))
+  if (gdk_screen_get_number (screen) != gdk_screen_get_number (gdk_window_get_screen (data->window)))
     {
       gdk_window_set_user_data (data->window, NULL);
       gdk_window_destroy (data->window);
@@ -381,7 +376,7 @@ filter (GdkXEvent *xevent,
                                            group,
                                            &keyval,
                                            NULL, NULL, NULL);
-      if (keyval == GDK_Control_L || keyval == GDK_Control_R)
+      if (keyval == GDK_KEY_Control_L || keyval == GDK_KEY_Control_R)
         {
           if (xev->type == KeyPress)
             {
@@ -418,7 +413,7 @@ set_locate_pointer (void)
   int n_screens;
   int n_keys;
   gboolean has_entries;
-  static const guint keyvals[] = { GDK_Control_L, GDK_Control_R };
+  static const guint keyvals[] = { GDK_KEY_Control_L, GDK_KEY_Control_R };
   unsigned j;
 
   display = gdk_display_get_default ();
